'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});

exports['default'] = function () {
    return {
        noColors: false,
        startTime: null,
        afterErrList: false,
        currentFixtureName: null,
        testCount: 0,

        reportTaskStart: function reportTaskStart(startTime, userAgents, testCount) {
            var _this = this;

            var uaList = userAgents.map(function (ua) {
                return _this.chalk.blue(ua);
            }).join(', ');

            this.startTime = startTime;
            this.testCount = testCount;

            this.setIndent(0).useWordWrap(true).write(this.chalk.bold('Running tests in: ' + uaList)).newline().newline();
        },

        reportFixtureStart: function reportFixtureStart(name) {
            this.currentFixtureName = name;
        },

        reportTestDone: function reportTestDone(name, errs, durationMs, unstable, screenshotPath) {
            var _this2 = this;

            var hasErr = !!errs.length;
            var nameStyle = hasErr ? this.chalk.red : this.chalk.gray;
            var symbol = hasErr ? this.chalk.red(this.symbols.err) : this.chalk.green(this.symbols.ok);

            name = this.currentFixtureName + ' - ' + name;

            var title = symbol + ' ' + nameStyle(name);

            if (unstable) title += this.chalk.yellow(' (unstable)');

            if (screenshotPath) title += ' (screenshots: ' + this.chalk.underline(screenshotPath) + ')';

            this.setIndent(2).useWordWrap(true).write(title);

            if (hasErr) {
                this.setIndent(6).newline();

                errs.forEach(function (err, idx) {
                    _this2.newline().write(_this2.formatError(err, idx + 1 + ') ')).newline().newline();
                });
            }

            this.afterErrList = hasErr;

            this.newline();
        },

        reportTaskDone: function reportTaskDone(endTime, passed) {
            var durationMs = endTime - this.startTime;
            var durationStr = this.moment.duration(durationMs).format('h[h] mm[m] ss[s]');
            var footer = passed === this.testCount ? this.chalk.bold.green(this.testCount + ' passed') : this.chalk.bold.red(this.testCount - passed + '/' + this.testCount + ' failed');

            footer += this.chalk.gray(' (' + durationStr + ')');

            this.setIndent(2).useWordWrap(true);

            if (!this.afterErrList) this.newline();

            this.newline().write(footer).newline();
        }
    };
};

module.exports = exports['default'];